
.. _install:

Installation
============

This describes the various installation methods for the SDSS sdss_access product.

Pip
---

The sdss_access product is now available as a Python package, and is pip-installable.  Simply do::

    pip install sdss-access

or to upgrage::

    pip install --upgrade sdss-access


